@@ -10,6 +10,7 @@ isRshared <- function(platform = .Platform) {
     }
 }
 
+## MM: cf. ~/R/Pkgs/robustbase/inst/xtraR/more
 sessionInfoX <- function(pkgs=NULL, list.libP = FALSE, extraR.env = TRUE) {
     ## return an object; then print() via method
     lP <- .libPaths() # *is* normalized in the sense of normalizePath()
@@ -22,10 +23,11 @@ sessionInfoX <- function(pkgs=NULL, list.libP = FALSE, extraR.env = TRUE) {
         pkgs <- sessionPkgs
     else if(!is.null(pkgs)) stopifnot(is.character(pkgs), length(pkgs) > 0)
     Rver <- package_version(si$R.version)
-    structure(class = "sessionInfoX",
+    struct(class = "sessionInfoX",
         list(sInfo  = si,
              sysInf = Sys.info(),
 	     capabilities = capabilities(),
+             Machine = .Machine,
 	     extSoft = if(Rver >= "3.2.0") extSoftVersion(),
 	     grSoft  = if(Rver >= "3.2.0") grSoftVersion(),
 	     tclVersion=if(Rver >= "3.2.0" && "tcltk" %in% sessionPkgs) tcltk::tclVersion(),
@@ -53,16 +55,17 @@ print.sessionInfoX <- function(x, locale = TRUE, RLIBS = TRUE, Renv = TRUE, ...)
     cat("Capabilities:\n")
     print(symnum(x$capabilities, symbols = c("-", "X")), ...)
     cat("Sys.info:\n")
-    print(structure(x$sysInf[c("nodename", "user")], class="Dlist"), ...)
+    print(struct(x$sysInf[c("nodename", "user")], class="Dlist"), ...)
+    cat(".Machine:  "); str(x$Machine)
     cat("\n")
     if(!is.null(x$LAPACK)) cat("LAPACK version:", x$LAPACK, "\n")
     if(!is.null(x$extSoft)) {
         cat("External software (versions):\n")
-        print(structure(x$extSoft, class="Dlist"), ...)
+        print(struct(x$extSoft, class="Dlist"), ...)
     }
     if(!is.null(x$grSoft)) {
         cat("Graphical software (versions):\n")
-        print(structure(x$grSoft, class="Dlist"), ...)
+        print(struct(x$grSoft, class="Dlist"), ...)
     }
     if(!is.null(x$tclVersion))
         cat("Tcl version:", x$tclVersion, "\n")
@@ -97,6 +100,9 @@ print.sessionInfoX <- function(x, locale = TRUE, RLIBS = TRUE, Renv = TRUE, ...)
     invisible(x)
 }
 
+## "FIXME"/"TODO":
+## used in  mtextVersion() in  ~/R/Pkgs/DPQ/inst/extraR/relErr-plots.R
+##  which mentions myRversion {long.double, non-{'x86_64'}}
 shortRversion <- function(Rv = R.version,
                           Rst = Rv$status,
                           Rvstring = if(!is.null(s <- Rv$version.string))
